Data Acquisition Module
=======================

.. autoclass:: zhinst.toolkit.control.drivers.base.DAQModule
    :members:

Result Class for the Data Acquisition Module
--------------------------------------------

.. autoclass:: zhinst.toolkit.control.drivers.base.daq.DAQResult
    :members: